This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Re: [patch/rfc] Deprecate USE_STRUCT_CONVENTION


Hello,

Now that return_value() covers edge cases such as RETURN_VALUE_ABI_RETURNS_ADDRESS and RETURN_VALUE_ABI_PRESERVES_ADDRESS, the old USE_STRUCT_CONVENTION is really redundant. This deprecates that method making it clear that it shouldn't be used in new architectures.

I'll look to commit in a week,
Andrew

The cross builds flushed out some tweaks that I missed. Here's the patch as committed.


Andrew

2004-06-20  Andrew Cagney  <cagney@gnu.org>

	* gdbarch.sh (DEPRECATED_USE_STRUCT_CONVENTION): Deprecated.
	* gdbarch.h, gdbarch.c: Re-generate.
	* values.c (using_struct_return): Update call.
	* mcore-tdep.c: Update comment.
	* infcall.c (call_function_by_hand): Update comment.
	* xstormy16-tdep.c (xstormy16_gdbarch_init): Update.
	* arch-utils.h (always_use_struct_convention): Update.
	* v850-tdep.c (v850_gdbarch_init): Update.
	* sh64-tdep.c (sh64_gdbarch_init): Update.
	* sh-tdep.c (sh_gdbarch_init): Update.
	* rs6000-tdep.c (rs6000_gdbarch_init): Update.
	* mips-tdep.c (mips_gdbarch_init): Update.
	* mcore-tdep.c (mcore_gdbarch_init): Update.
	* m32r-tdep.c (m32r_gdbarch_init): Update.
	* ia64-tdep.c (ia64_gdbarch_init): Update.
	* h8300-tdep.c (h8300_gdbarch_init): Update.
	* frv-tdep.c (frv_gdbarch_init): Update.
	* cris-tdep.c (cris_gdbarch_init): Update.
	* arm-tdep.c (arm_gdbarch_init): Update.
	* alpha-tdep.c (alpha_gdbarch_init): Update.

Index: doc/ChangeLog
2004-06-20  Andrew Cagney  <cagney@gnu.org>

	* gdbint.texinfo (Target Architecture Definition): Deprecate
	USE_STRUCT_CONVENTION.

Index: alpha-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/alpha-tdep.c,v
retrieving revision 1.132
diff -p -u -r1.132 alpha-tdep.c
--- alpha-tdep.c	7 Jun 2004 02:02:45 -0000	1.132
+++ alpha-tdep.c	20 Jun 2004 17:16:31 -0000
@@ -1550,7 +1550,7 @@ alpha_gdbarch_init (struct gdbarch_info 
 
   /* Call info.  */
 
-  set_gdbarch_use_struct_convention (gdbarch, always_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, always_use_struct_convention);
   set_gdbarch_extract_return_value (gdbarch, alpha_extract_return_value);
   set_gdbarch_store_return_value (gdbarch, alpha_store_return_value);
   set_gdbarch_deprecated_extract_struct_value_address (gdbarch, alpha_extract_struct_value_address);
Index: alphafbsd-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/alphafbsd-tdep.c,v
retrieving revision 1.13
diff -p -u -r1.13 alphafbsd-tdep.c
--- alphafbsd-tdep.c	1 May 2004 15:34:49 -0000	1.13
+++ alphafbsd-tdep.c	20 Jun 2004 17:16:31 -0000
@@ -98,7 +98,7 @@ alphafbsd_init_abi (struct gdbarch_info 
   /* Hook into the MDEBUG frame unwinder.  */
   alpha_mdebug_init_abi (info, gdbarch);
 
-  set_gdbarch_use_struct_convention (gdbarch, alphafbsd_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, alphafbsd_use_struct_convention);
 
   tdep->dynamic_sigtramp_offset = alphafbsd_sigtramp_offset;
   tdep->sigcontext_addr = alphafbsd_sigcontext_addr;
Index: arch-utils.h
===================================================================
RCS file: /cvs/src/src/gdb/arch-utils.h,v
retrieving revision 1.72
diff -p -u -r1.72 arch-utils.h
--- arch-utils.h	13 Jun 2004 13:42:31 -0000	1.72
+++ arch-utils.h	20 Jun 2004 17:16:31 -0000
@@ -41,7 +41,7 @@ extern gdbarch_store_return_value_ftype 
 
 /* To return any structure or union type by value, store it at the
    address passed as an invisible first argument to the function.  */
-extern gdbarch_use_struct_convention_ftype always_use_struct_convention;
+extern gdbarch_deprecated_use_struct_convention_ftype always_use_struct_convention;
 
 /* Typical remote_translate_xfer_address */
 extern gdbarch_remote_translate_xfer_address_ftype generic_remote_translate_xfer_address;
Index: arm-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/arm-tdep.c,v
retrieving revision 1.176
diff -p -u -r1.176 arm-tdep.c
--- arm-tdep.c	18 Jun 2004 21:36:15 -0000	1.176
+++ arm-tdep.c	20 Jun 2004 17:16:32 -0000
@@ -2762,7 +2762,7 @@ arm_gdbarch_init (struct gdbarch_info in
   /* Returning results.  */
   set_gdbarch_extract_return_value (gdbarch, arm_extract_return_value);
   set_gdbarch_store_return_value (gdbarch, arm_store_return_value);
-  set_gdbarch_use_struct_convention (gdbarch, arm_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, arm_use_struct_convention);
   set_gdbarch_deprecated_extract_struct_value_address (gdbarch, arm_extract_struct_value_address);
 
   /* Single stepping.  */
Index: cris-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/cris-tdep.c,v
retrieving revision 1.107
diff -p -u -r1.107 cris-tdep.c
--- cris-tdep.c	13 Jun 2004 13:49:53 -0000	1.107
+++ cris-tdep.c	20 Jun 2004 17:16:32 -0000
@@ -3795,7 +3795,7 @@ cris_gdbarch_init (struct gdbarch_info i
   set_gdbarch_return_value (gdbarch, cris_return_value);
   set_gdbarch_deprecated_reg_struct_has_addr (gdbarch, 
 					      cris_reg_struct_has_addr);
-  set_gdbarch_use_struct_convention (gdbarch, always_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, always_use_struct_convention);
 
   /* There are 32 registers (some of which may not be implemented).  */
   set_gdbarch_num_regs (gdbarch, 32);
Index: frv-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/frv-tdep.c,v
retrieving revision 1.84
diff -p -u -r1.84 frv-tdep.c
--- frv-tdep.c	7 Jun 2004 02:02:46 -0000	1.84
+++ frv-tdep.c	20 Jun 2004 17:16:32 -0000
@@ -1498,7 +1498,7 @@ frv_gdbarch_init (struct gdbarch_info in
 
   set_gdbarch_deprecated_frameless_function_invocation (gdbarch, frv_frameless_function_invocation);
 
-  set_gdbarch_use_struct_convention (gdbarch, always_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, always_use_struct_convention);
   set_gdbarch_extract_return_value (gdbarch, frv_extract_return_value);
 
   set_gdbarch_deprecated_store_struct_return (gdbarch, frv_store_struct_return);
Index: h8300-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/h8300-tdep.c,v
retrieving revision 1.95
diff -p -u -r1.95 h8300-tdep.c
--- h8300-tdep.c	10 Jun 2004 13:22:06 -0000	1.95
+++ h8300-tdep.c	20 Jun 2004 17:16:33 -0000
@@ -1320,7 +1320,7 @@ h8300_gdbarch_init (struct gdbarch_info 
   set_gdbarch_deprecated_frameless_function_invocation (gdbarch, legacy_frameless_look_for_prologue);
 
   set_gdbarch_deprecated_extract_struct_value_address (gdbarch, h8300_extract_struct_value_address);
-  set_gdbarch_use_struct_convention (gdbarch, always_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, always_use_struct_convention);
   set_gdbarch_breakpoint_from_pc (gdbarch, h8300_breakpoint_from_pc);
   set_gdbarch_push_dummy_code (gdbarch, h8300_push_dummy_code);
   set_gdbarch_push_dummy_call (gdbarch, h8300_push_dummy_call);
Index: ia64-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/ia64-tdep.c,v
retrieving revision 1.123
diff -p -u -r1.123 ia64-tdep.c
--- ia64-tdep.c	7 Jun 2004 02:02:50 -0000	1.123
+++ ia64-tdep.c	20 Jun 2004 17:16:34 -0000
@@ -99,7 +99,6 @@ static gdbarch_register_type_ftype ia64_
 static gdbarch_breakpoint_from_pc_ftype ia64_breakpoint_from_pc;
 static gdbarch_skip_prologue_ftype ia64_skip_prologue;
 static gdbarch_extract_return_value_ftype ia64_extract_return_value;
-static gdbarch_use_struct_convention_ftype ia64_use_struct_convention;
 static struct type *is_float_or_hfa_type (struct type *t);
 
 static struct type *builtin_type_ia64_ext;
@@ -3334,7 +3333,7 @@ ia64_gdbarch_init (struct gdbarch_info i
 
   set_gdbarch_skip_prologue (gdbarch, ia64_skip_prologue);
 
-  set_gdbarch_use_struct_convention (gdbarch, ia64_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, ia64_use_struct_convention);
   set_gdbarch_extract_return_value (gdbarch, ia64_extract_return_value);
 
   set_gdbarch_store_return_value (gdbarch, ia64_store_return_value);
Index: infcall.c
===================================================================
RCS file: /cvs/src/src/gdb/infcall.c,v
retrieving revision 1.51
diff -p -u -r1.51 infcall.c
--- infcall.c	18 Jun 2004 21:36:15 -0000	1.51
+++ infcall.c	20 Jun 2004 17:16:34 -0000
@@ -953,9 +953,9 @@ the function call).", name);
     else
       {
 	/* NOTE: cagney/2003-10-20: Unlike "gdbarch_return_value", the
-	   EXTRACT_RETURN_VALUE and USE_STRUCT_CONVENTION methods do
-	   not handle the edge case of a function returning a small
-	   structure / union in registers.  */
+	   EXTRACT_RETURN_VALUE and DEPRECATED_USE_STRUCT_CONVENTION
+	   methods do not handle the edge case of a function returning
+	   a small structure / union in registers.  */
 	retval = allocate_value (value_type);
 	EXTRACT_RETURN_VALUE (value_type, retbuf, VALUE_CONTENTS_RAW (retval));
       }
Index: m32r-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/m32r-tdep.c,v
retrieving revision 1.27
diff -p -u -r1.27 m32r-tdep.c
--- m32r-tdep.c	7 Jun 2004 02:02:50 -0000	1.27
+++ m32r-tdep.c	20 Jun 2004 17:16:34 -0000
@@ -930,7 +930,7 @@ m32r_gdbarch_init (struct gdbarch_info i
   set_gdbarch_push_dummy_call (gdbarch, m32r_push_dummy_call);
   set_gdbarch_store_return_value (gdbarch, m32r_store_return_value);
   set_gdbarch_deprecated_extract_struct_value_address (gdbarch, m32r_extract_struct_value_address);
-  set_gdbarch_use_struct_convention (gdbarch, m32r_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, m32r_use_struct_convention);
 
   set_gdbarch_skip_prologue (gdbarch, m32r_skip_prologue);
   set_gdbarch_inner_than (gdbarch, core_addr_lessthan);
Index: mcore-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/mcore-tdep.c,v
retrieving revision 1.90
diff -p -u -r1.90 mcore-tdep.c
--- mcore-tdep.c	13 Jun 2004 13:49:53 -0000	1.90
+++ mcore-tdep.c	20 Jun 2004 17:16:34 -0000
@@ -916,11 +916,11 @@ mcore_push_return_address (CORE_ADDR pc,
    argument.
 
    For gdb, this leaves us two routes, based on what
-   USE_STRUCT_CONVENTION (mcore_use_struct_convention) returns.  If
-   this macro returns 1, gdb will call STORE_STRUCT_RETURN to store
-   the return value.
+   DEPRECATED_USE_STRUCT_CONVENTION (mcore_use_struct_convention)
+   returns.  If this macro returns 1, gdb will call
+   STORE_STRUCT_RETURN to store the return value.
 
-   If USE_STRUCT_CONVENTION returns 0, then gdb uses
+   If DEPRECATED_USE_STRUCT_CONVENTION returns 0, then gdb uses
    STORE_RETURN_VALUE and EXTRACT_RETURN_VALUE to store/fetch the
    functions return value.  */
 
@@ -1074,7 +1074,7 @@ mcore_gdbarch_init (struct gdbarch_info 
 
   /* Stack grows down.  */
   set_gdbarch_inner_than (gdbarch, core_addr_lessthan);
-  set_gdbarch_use_struct_convention (gdbarch, mcore_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, mcore_use_struct_convention);
   set_gdbarch_believe_pcc_promotion (gdbarch, 1);
   /* MCore will never pass a sturcture by reference. It will always be split
      between registers and stack.  */
Index: mips-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/mips-tdep.c,v
retrieving revision 1.298
diff -p -u -r1.298 mips-tdep.c
--- mips-tdep.c	15 Jun 2004 15:06:57 -0000	1.298
+++ mips-tdep.c	20 Jun 2004 17:16:34 -0000
@@ -5645,8 +5645,7 @@ mips_gdbarch_init (struct gdbarch_info i
       set_gdbarch_long_bit (gdbarch, 32);
       set_gdbarch_ptr_bit (gdbarch, 32);
       set_gdbarch_long_long_bit (gdbarch, 64);
-      set_gdbarch_use_struct_convention (gdbarch,
-					 always_use_struct_convention);
+      set_gdbarch_deprecated_use_struct_convention (gdbarch, always_use_struct_convention);
       break;
     case MIPS_ABI_EABI32:
       set_gdbarch_push_dummy_call (gdbarch, mips_eabi_push_dummy_call);
@@ -5662,8 +5661,7 @@ mips_gdbarch_init (struct gdbarch_info i
       set_gdbarch_long_long_bit (gdbarch, 64);
       set_gdbarch_deprecated_reg_struct_has_addr
 	(gdbarch, mips_eabi_reg_struct_has_addr);
-      set_gdbarch_use_struct_convention (gdbarch,
-					 mips_eabi_use_struct_convention);
+      set_gdbarch_deprecated_use_struct_convention (gdbarch, mips_eabi_use_struct_convention);
       break;
     case MIPS_ABI_EABI64:
       set_gdbarch_push_dummy_call (gdbarch, mips_eabi_push_dummy_call);
@@ -5679,8 +5677,7 @@ mips_gdbarch_init (struct gdbarch_info i
       set_gdbarch_long_long_bit (gdbarch, 64);
       set_gdbarch_deprecated_reg_struct_has_addr
 	(gdbarch, mips_eabi_reg_struct_has_addr);
-      set_gdbarch_use_struct_convention (gdbarch,
-					 mips_eabi_use_struct_convention);
+      set_gdbarch_deprecated_use_struct_convention (gdbarch, mips_eabi_use_struct_convention);
       break;
     case MIPS_ABI_N32:
       set_gdbarch_push_dummy_call (gdbarch, mips_n32n64_push_dummy_call);
Index: rs6000-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/rs6000-tdep.c,v
retrieving revision 1.214
diff -p -u -r1.214 rs6000-tdep.c
--- rs6000-tdep.c	7 Jun 2004 23:37:20 -0000	1.214
+++ rs6000-tdep.c	20 Jun 2004 17:16:34 -0000
@@ -3028,8 +3028,7 @@ rs6000_gdbarch_init (struct gdbarch_info
   set_gdbarch_frame_args_skip (gdbarch, 8);
 
   if (!sysv_abi)
-    set_gdbarch_use_struct_convention (gdbarch,
-				       rs6000_use_struct_convention);
+    set_gdbarch_deprecated_use_struct_convention (gdbarch, rs6000_use_struct_convention);
 
   if (!sysv_abi)
     {
Index: sh-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/sh-tdep.c,v
retrieving revision 1.169
diff -p -u -r1.169 sh-tdep.c
--- sh-tdep.c	7 Jun 2004 02:02:54 -0000	1.169
+++ sh-tdep.c	20 Jun 2004 17:16:34 -0000
@@ -2215,7 +2215,7 @@ sh_gdbarch_init (struct gdbarch_info inf
   set_gdbarch_print_registers_info (gdbarch, sh_print_registers_info);
 
   set_gdbarch_breakpoint_from_pc (gdbarch, sh_breakpoint_from_pc);
-  set_gdbarch_use_struct_convention (gdbarch, sh_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, sh_use_struct_convention);
 
   set_gdbarch_print_insn (gdbarch, gdb_print_insn_sh);
   set_gdbarch_register_sim_regno (gdbarch, legacy_register_sim_regno);
Index: sh64-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/sh64-tdep.c,v
retrieving revision 1.28
diff -p -u -r1.28 sh64-tdep.c
--- sh64-tdep.c	10 Jun 2004 13:22:07 -0000	1.28
+++ sh64-tdep.c	20 Jun 2004 17:16:35 -0000
@@ -2875,7 +2875,7 @@ sh64_gdbarch_init (struct gdbarch_info i
   set_gdbarch_deprecated_dummy_write_sp (gdbarch, deprecated_write_sp);
   set_gdbarch_deprecated_store_struct_return (gdbarch, sh64_store_struct_return);
   set_gdbarch_deprecated_extract_struct_value_address (gdbarch, sh64_extract_struct_value_address);
-  set_gdbarch_use_struct_convention (gdbarch, sh64_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, sh64_use_struct_convention);
   set_gdbarch_deprecated_pop_frame (gdbarch, sh64_pop_frame);
   set_gdbarch_elf_make_msymbol_special (gdbarch,
 					sh64_elf_make_msymbol_special);
Index: v850-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/v850-tdep.c,v
retrieving revision 1.88
diff -p -u -r1.88 v850-tdep.c
--- v850-tdep.c	13 Jun 2004 13:49:53 -0000	1.88
+++ v850-tdep.c	20 Jun 2004 17:16:35 -0000
@@ -1225,7 +1225,7 @@ v850_gdbarch_init (struct gdbarch_info i
   set_gdbarch_deprecated_pop_frame (gdbarch, v850_pop_frame);
   set_gdbarch_deprecated_store_struct_return (gdbarch, v850_store_struct_return);
   set_gdbarch_deprecated_store_return_value (gdbarch, v850_store_return_value);
-  set_gdbarch_use_struct_convention (gdbarch, v850_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, v850_use_struct_convention);
   set_gdbarch_breakpoint_from_pc (gdbarch, v850_breakpoint_from_pc);
 
   set_gdbarch_int_bit (gdbarch, 4 * TARGET_CHAR_BIT);
Index: values.c
===================================================================
RCS file: /cvs/src/src/gdb/values.c,v
retrieving revision 1.68
diff -p -u -r1.68 values.c
--- values.c	13 Jun 2004 15:15:59 -0000	1.68
+++ values.c	20 Jun 2004 17:16:35 -0000
@@ -1256,7 +1256,7 @@ using_struct_return (struct type *value_
       if (code == TYPE_CODE_STRUCT
 	  || code == TYPE_CODE_UNION
 	  || code == TYPE_CODE_ARRAY)
-	return USE_STRUCT_CONVENTION (gcc_p, value_type);
+	return DEPRECATED_USE_STRUCT_CONVENTION (gcc_p, value_type);
       else
 	return 0;
     }
Index: xstormy16-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/xstormy16-tdep.c,v
retrieving revision 1.78
diff -p -u -r1.78 xstormy16-tdep.c
--- xstormy16-tdep.c	13 Jun 2004 13:49:53 -0000	1.78
+++ xstormy16-tdep.c	20 Jun 2004 17:16:35 -0000
@@ -1167,8 +1167,7 @@ xstormy16_gdbarch_init (struct gdbarch_i
   set_gdbarch_deprecated_store_struct_return (gdbarch, xstormy16_store_struct_return);
   set_gdbarch_deprecated_store_return_value (gdbarch, xstormy16_store_return_value);
   set_gdbarch_deprecated_extract_struct_value_address (gdbarch, xstormy16_extract_struct_value_address);
-  set_gdbarch_use_struct_convention (gdbarch,
-				     xstormy16_use_struct_convention);
+  set_gdbarch_deprecated_use_struct_convention (gdbarch, xstormy16_use_struct_convention);
   set_gdbarch_breakpoint_from_pc (gdbarch, xstormy16_breakpoint_from_pc);
 
   set_gdbarch_char_signed (gdbarch, 0);
Index: doc/gdbint.texinfo
===================================================================
RCS file: /cvs/src/src/gdb/doc/gdbint.texinfo,v
retrieving revision 1.210
diff -p -u -r1.210 gdbint.texinfo
--- doc/gdbint.texinfo	18 Jun 2004 21:36:16 -0000	1.210
+++ doc/gdbint.texinfo	20 Jun 2004 17:16:36 -0000
@@ -3893,8 +3893,8 @@ frame.  The value returned must match th
 previously saved using @code{SAVE_DUMMY_FRAME_TOS}.
 @xref{SAVE_DUMMY_FRAME_TOS}.
 
-@item USE_STRUCT_CONVENTION (@var{gcc_p}, @var{type})
-@findex USE_STRUCT_CONVENTION
+@item DEPRECATED_USE_STRUCT_CONVENTION (@var{gcc_p}, @var{type})
+@findex DEPRECATED_USE_STRUCT_CONVENTION
 If defined, this must be an expression that is nonzero if a value of the
 given @var{type} being returned from a function must have space
 allocated for it on the stack.  @var{gcc_p} is true if the function

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: gdbarch.c
===================================================================
RCS file: /cvs/src/src/gdb/gdbarch.c,v
retrieving revision 1.297
diff -p -u -r1.297 gdbarch.c
--- gdbarch.c	18 Jun 2004 21:36:15 -0000	1.297
+++ gdbarch.c	20 Jun 2004 17:16:33 -0000
@@ -186,7 +186,7 @@ struct gdbarch
   gdbarch_store_return_value_ftype *store_return_value;
   gdbarch_deprecated_extract_return_value_ftype *deprecated_extract_return_value;
   gdbarch_deprecated_store_return_value_ftype *deprecated_store_return_value;
-  gdbarch_use_struct_convention_ftype *use_struct_convention;
+  gdbarch_deprecated_use_struct_convention_ftype *deprecated_use_struct_convention;
   gdbarch_deprecated_extract_struct_value_address_ftype *deprecated_extract_struct_value_address;
   gdbarch_deprecated_frame_init_saved_regs_ftype *deprecated_frame_init_saved_regs;
   gdbarch_deprecated_init_extra_frame_info_ftype *deprecated_init_extra_frame_info;
@@ -332,7 +332,7 @@ struct gdbarch startup_gdbarch =
   0,  /* store_return_value */
   0,  /* deprecated_extract_return_value */
   0,  /* deprecated_store_return_value */
-  0,  /* use_struct_convention */
+  0,  /* deprecated_use_struct_convention */
   0,  /* deprecated_extract_struct_value_address */
   0,  /* deprecated_frame_init_saved_regs */
   0,  /* deprecated_init_extra_frame_info */
@@ -459,7 +459,7 @@ gdbarch_alloc (const struct gdbarch_info
   current_gdbarch->address_to_pointer = unsigned_address_to_pointer;
   current_gdbarch->extract_return_value = legacy_extract_return_value;
   current_gdbarch->store_return_value = legacy_store_return_value;
-  current_gdbarch->use_struct_convention = generic_use_struct_convention;
+  current_gdbarch->deprecated_use_struct_convention = generic_use_struct_convention;
   current_gdbarch->memory_insert_breakpoint = default_memory_insert_breakpoint;
   current_gdbarch->memory_remove_breakpoint = default_memory_remove_breakpoint;
   current_gdbarch->remote_translate_xfer_address = generic_remote_translate_xfer_address;
@@ -604,7 +604,7 @@ verify_gdbarch (struct gdbarch *current_
   /* Skip verify of return_value, has predicate */
   /* Skip verify of extract_return_value, invalid_p == 0 */
   /* Skip verify of store_return_value, invalid_p == 0 */
   /* Skip verify of use_struct_convention, invalid_p == 0 */
   /* Skip verify of deprecated_extract_struct_value_address, has predicate */
   /* Skip verify of deprecated_frame_init_saved_regs, has predicate */
   /* Skip verify of deprecated_init_extra_frame_info, has predicate */
@@ -1422,6 +1422,16 @@ gdbarch_dump (struct gdbarch *current_gd
                       (long) current_gdbarch->deprecated_target_read_fp
                       /*DEPRECATED_TARGET_READ_FP ()*/);
 #endif
+#ifdef DEPRECATED_USE_STRUCT_CONVENTION
+  fprintf_unfiltered (file,
+                      "gdbarch_dump: %s # %s\n",
+                      "DEPRECATED_USE_STRUCT_CONVENTION(gcc_p, value_type)",
+                      XSTRING (DEPRECATED_USE_STRUCT_CONVENTION (gcc_p, value_type)));
+  fprintf_unfiltered (file,
+                      "gdbarch_dump: DEPRECATED_USE_STRUCT_CONVENTION = <0x%08lx>\n",
+                      (long) current_gdbarch->deprecated_use_struct_convention
+                      /*DEPRECATED_USE_STRUCT_CONVENTION ()*/);
+#endif
 #ifdef DWARF2_REG_TO_REGNUM
   fprintf_unfiltered (file,
                       "gdbarch_dump: %s # %s\n",
@@ -2078,16 +2088,6 @@ gdbarch_dump (struct gdbarch *current_gd
   fprintf_unfiltered (file,
                       "gdbarch_dump: unwind_sp = 0x%08lx\n",
                       (long) current_gdbarch->unwind_sp);
-#ifdef USE_STRUCT_CONVENTION
-  fprintf_unfiltered (file,
-                      "gdbarch_dump: %s # %s\n",
-                      "USE_STRUCT_CONVENTION(gcc_p, value_type)",
-                      XSTRING (USE_STRUCT_CONVENTION (gcc_p, value_type)));
-  fprintf_unfiltered (file,
-                      "gdbarch_dump: USE_STRUCT_CONVENTION = <0x%08lx>\n",
-                      (long) current_gdbarch->use_struct_convention
-                      /*USE_STRUCT_CONVENTION ()*/);
-#endif
 #ifdef VALUE_TO_REGISTER
   fprintf_unfiltered (file,
                       "gdbarch_dump: %s # %s\n",
@@ -3545,20 +3545,20 @@ set_gdbarch_deprecated_store_return_valu
 }
 
 int
-gdbarch_use_struct_convention (struct gdbarch *gdbarch, int gcc_p, struct type *value_type)
+gdbarch_deprecated_use_struct_convention (struct gdbarch *gdbarch, int gcc_p, struct type *value_type)
 {
   gdb_assert (gdbarch != NULL);
-  gdb_assert (gdbarch->use_struct_convention != NULL);
+  gdb_assert (gdbarch->deprecated_use_struct_convention != NULL);
   if (gdbarch_debug >= 2)
-    fprintf_unfiltered (gdb_stdlog, "gdbarch_use_struct_convention called\n");
-  return gdbarch->use_struct_convention (gcc_p, value_type);
+    fprintf_unfiltered (gdb_stdlog, "gdbarch_deprecated_use_struct_convention called\n");
+  return gdbarch->deprecated_use_struct_convention (gcc_p, value_type);
 }
 
 void
-set_gdbarch_use_struct_convention (struct gdbarch *gdbarch,
-                                   gdbarch_use_struct_convention_ftype use_struct_convention)
+set_gdbarch_deprecated_use_struct_convention (struct gdbarch *gdbarch,
+                                              gdbarch_deprecated_use_struct_convention_ftype deprecated_use_struct_convention)
 {
-  gdbarch->use_struct_convention = use_struct_convention;
+  gdbarch->deprecated_use_struct_convention = deprecated_use_struct_convention;
 }
 
 int
@@ -604,7 +604,7 @@ verify_gdbarch (struct gdbarch *current_
   /* Skip verify of extract_return_value, invalid_p == 0 */
   /* Skip verify of store_return_value, invalid_p == 0 */
-  /* Skip verify of use_struct_convention, invalid_p == 0 */
+  /* Skip verify of deprecated_use_struct_convention, invalid_p == 0 */
   /* Skip verify of deprecated_extract_struct_value_address, has predicate */
   /* Skip verify of deprecated_frame_init_saved_regs, has predicate */
Index: gdbarch.h
===================================================================
RCS file: /cvs/src/src/gdb/gdbarch.h,v
retrieving revision 1.261
diff -p -u -r1.261 gdbarch.h
--- gdbarch.h	18 Jun 2004 21:36:15 -0000	1.261
+++ gdbarch.h	20 Jun 2004 17:16:33 -0000
@@ -1101,8 +1101,10 @@ typedef enum return_value_convention (gd
 extern enum return_value_convention gdbarch_return_value (struct gdbarch *gdbarch, struct type *valtype, struct regcache *regcache, void *readbuf, const void *writebuf);
 extern void set_gdbarch_return_value (struct gdbarch *gdbarch, gdbarch_return_value_ftype *return_value);
 
-/* The deprecated methods EXTRACT_RETURN_VALUE, STORE_RETURN_VALUE and
-   USE_STRUCT_CONVENTION have all been folded into RETURN_VALUE. */
+/* The deprecated methods EXTRACT_RETURN_VALUE, STORE_RETURN_VALUE,
+   DEPRECATED_EXTRACT_STRUCT_VALUE_ADDRESS and
+   DEPRECATED_USE_STRUCT_CONVENTION have all been folded into
+   RETURN_VALUE. */
 
 typedef void (gdbarch_extract_return_value_ftype) (struct type *type, struct regcache *regcache, void *valbuf);
 extern void gdbarch_extract_return_value (struct gdbarch *gdbarch, struct type *type, struct regcache *regcache, void *valbuf);
@@ -1144,14 +1146,14 @@ extern void set_gdbarch_deprecated_store
 #define DEPRECATED_STORE_RETURN_VALUE(type, valbuf) (gdbarch_deprecated_store_return_value (current_gdbarch, type, valbuf))
 #endif
 
-typedef int (gdbarch_use_struct_convention_ftype) (int gcc_p, struct type *value_type);
-extern int gdbarch_use_struct_convention (struct gdbarch *gdbarch, int gcc_p, struct type *value_type);
-extern void set_gdbarch_use_struct_convention (struct gdbarch *gdbarch, gdbarch_use_struct_convention_ftype *use_struct_convention);
-#if (GDB_MULTI_ARCH > GDB_MULTI_ARCH_PARTIAL) && defined (USE_STRUCT_CONVENTION)
-#error "Non multi-arch definition of USE_STRUCT_CONVENTION"
+typedef int (gdbarch_deprecated_use_struct_convention_ftype) (int gcc_p, struct type *value_type);
+extern int gdbarch_deprecated_use_struct_convention (struct gdbarch *gdbarch, int gcc_p, struct type *value_type);
+extern void set_gdbarch_deprecated_use_struct_convention (struct gdbarch *gdbarch, gdbarch_deprecated_use_struct_convention_ftype *deprecated_use_struct_convention);
+#if (GDB_MULTI_ARCH > GDB_MULTI_ARCH_PARTIAL) && defined (DEPRECATED_USE_STRUCT_CONVENTION)
+#error "Non multi-arch definition of DEPRECATED_USE_STRUCT_CONVENTION"
 #endif
-#if !defined (USE_STRUCT_CONVENTION)
-#define USE_STRUCT_CONVENTION(gcc_p, value_type) (gdbarch_use_struct_convention (current_gdbarch, gcc_p, value_type))
+#if !defined (DEPRECATED_USE_STRUCT_CONVENTION)
+#define DEPRECATED_USE_STRUCT_CONVENTION(gcc_p, value_type) (gdbarch_deprecated_use_struct_convention (current_gdbarch, gcc_p, value_type))
 #endif
 
 /* As of 2004-01-17 only the 32-bit SPARC ABI has been identified as an
Index: gdbarch.sh
===================================================================
RCS file: /cvs/src/src/gdb/gdbarch.sh,v
retrieving revision 1.326
diff -p -u -r1.326 gdbarch.sh
--- gdbarch.sh	18 Jun 2004 21:36:15 -0000	1.326
+++ gdbarch.sh	20 Jun 2004 17:16:33 -0000
@@ -543,14 +543,16 @@ F:DEPRECATED_STORE_STRUCT_RETURN:void:de
 
 M::enum return_value_convention:return_value:struct type *valtype, struct regcache *regcache, void *readbuf, const void *writebuf:valtype, regcache, readbuf, writebuf
 
 # The deprecated methods EXTRACT_RETURN_VALUE, STORE_RETURN_VALUE and
 # USE_STRUCT_CONVENTION have all been folded into RETURN_VALUE.
 
 f:EXTRACT_RETURN_VALUE:void:extract_return_value:struct type *type, struct regcache *regcache, void *valbuf:type, regcache, valbuf:::legacy_extract_return_value::0
 f:STORE_RETURN_VALUE:void:store_return_value:struct type *type, struct regcache *regcache, const void *valbuf:type, regcache, valbuf:::legacy_store_return_value::0
 f:DEPRECATED_EXTRACT_RETURN_VALUE:void:deprecated_extract_return_value:struct type *type, char *regbuf, char *valbuf:type, regbuf, valbuf
 f:DEPRECATED_STORE_RETURN_VALUE:void:deprecated_store_return_value:struct type *type, char *valbuf:type, valbuf
-f:USE_STRUCT_CONVENTION:int:use_struct_convention:int gcc_p, struct type *value_type:gcc_p, value_type:::generic_use_struct_convention::0
+f:DEPRECATED_USE_STRUCT_CONVENTION:int:deprecated_use_struct_convention:int gcc_p, struct type *value_type:gcc_p, value_type:::generic_use_struct_convention::0
 
 # As of 2004-01-17 only the 32-bit SPARC ABI has been identified as an
 # ABI suitable for the implementation of a robust extract
@@ -543,14 +543,16 @@ F:DEPRECATED_STORE_STRUCT_RETURN:void:de
 M::enum return_value_convention:return_value:struct type *valtype, struct regcache *regcache, void *readbuf, const void *writebuf:valtype, regcache, readbuf, writebuf
 
-# The deprecated methods EXTRACT_RETURN_VALUE, STORE_RETURN_VALUE and
-# USE_STRUCT_CONVENTION have all been folded into RETURN_VALUE.
+# The deprecated methods EXTRACT_RETURN_VALUE, STORE_RETURN_VALUE,
+# DEPRECATED_EXTRACT_STRUCT_VALUE_ADDRESS and
+# DEPRECATED_USE_STRUCT_CONVENTION have all been folded into
+# RETURN_VALUE.
 
 f:EXTRACT_RETURN_VALUE:void:extract_return_value:struct type *type, struct regcache *regcache, void *valbuf:type, regcache, valbuf:::legacy_extract_return_value::0